==> xnu-1504.15.3.tar.gz: xnu-xnu-1504.15.3/libkern/kxld/kxld_uuid.c <==
/*
 * Copyright (c) 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#include <string.h>
#include <mach-o/loader.h>
#include <sys/types.h>

#define DEBUG_ASSERT_COMPONENT_NAME_STRING "kxld"
#include <AssertMacros.h>

#include "kxld_util.h"
#include "kxld_uuid.h"

/*******************************************************************************
*******************************************************************************/
void
kxld_uuid_init_from_macho(KXLDuuid *uuid, struct uuid_command *src)
{
    check(uuid);
    check(src);

    memcpy(uuid->uuid, src->uuid, sizeof(uuid->uuid));
    uuid->has_uuid = TRUE;
}

/*******************************************************************************
*******************************************************************************/
void
kxld_uuid_clear(KXLDuuid *uuid)
{
    bzero(uuid, sizeof(*uuid));
}

/*******************************************************************************
*******************************************************************************/
u_long
kxld_uuid_get_macho_header_size(void)
{
    return sizeof(struct uuid_command);
}

/*******************************************************************************
*******************************************************************************/
kern_return_t
kxld_uuid_export_macho(const KXLDuuid *uuid, u_char *buf, 
    u_long *header_offset, u_long header_size)
{
    kern_return_t rval = KERN_FAILURE;
    struct uuid_command *uuidhdr = NULL;

    check(uuid);
    check(buf);
    check(header_offset);

    require_action(sizeof(*uuidhdr) <= header_size - *header_offset, finish,
        rval=KERN_FAILURE);
    uuidhdr = (struct uuid_command *) (buf + *header_offset);
    *header_offset += sizeof(*uuidhdr);

    uuidhdr->cmd = LC_UUID;
    uuidhdr->cmdsize = (uint32_t) sizeof(*uuidhdr);
    memcpy(uuidhdr->uuid, uuid->uuid, sizeof(uuidhdr->uuid));

    rval = KERN_SUCCESS;

finish:
    return rval;
}

==> xnu-10002.1.13.tar.gz: xnu-xnu-10002.1.13/libkern/kxld/kxld_uuid.c <==
/*
 * Copyright (c) 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#include <string.h>
#include <mach-o/loader.h>
#include <sys/types.h>

#define DEBUG_ASSERT_COMPONENT_NAME_STRING "kxld"
#include <AssertMacros.h>

#include "kxld_util.h"
#include "kxld_uuid.h"

/*******************************************************************************
*******************************************************************************/
void
kxld_uuid_init_from_macho(KXLDuuid *uuid, struct uuid_command *src)
{
	check(uuid);
	check(src);

	memcpy(uuid->uuid, src->uuid, sizeof(uuid->uuid));
	uuid->has_uuid = TRUE;
}

/*******************************************************************************
*******************************************************************************/
void
kxld_uuid_clear(KXLDuuid *uuid)
{
	bzero(uuid, sizeof(*uuid));
}

/*******************************************************************************
*******************************************************************************/
u_long
kxld_uuid_get_macho_header_size(void)
{
	return sizeof(struct uuid_command);
}

/*******************************************************************************
*******************************************************************************/
kern_return_t
kxld_uuid_export_macho(const KXLDuuid *uuid, u_char *buf,
    u_long *header_offset, u_long header_size)
{
	kern_return_t rval = KERN_FAILURE;
	struct uuid_command *uuidhdr = NULL;

	check(uuid);
	check(buf);
	check(header_offset);

	require_action(sizeof(*uuidhdr) <= header_size - *header_offset, finish,
	    rval = KERN_FAILURE);
	uuidhdr = (struct uuid_command *) ((void *) (buf + *header_offset));
	*header_offset += sizeof(*uuidhdr);

	uuidhdr->cmd = LC_UUID;
	uuidhdr->cmdsize = (uint32_t) sizeof(*uuidhdr);
	memcpy(uuidhdr->uuid, uuid->uuid, sizeof(uuidhdr->uuid));

	rval = KERN_SUCCESS;

finish:
	return rval;
}
